@@ -9,10 +9,7 @@ Directives for shield/badge images.
 Usage
 ---------
 
-Several shield/badge directives are available, like this one: |demo|
-
-.. |demo| pre-commit-shield::
-
+Several shield/badge directives are available.
 
 They function similarly to the ``.. image::`` directives, although not all options are available.
 As with the image directive, shields can be used as part of substitutions, e.g.
@@ -45,6 +42,10 @@ All shields have the following options:
 	All shields have the ``sphinx_toolbox_shield`` class by default.
 
 
+.. latex:clearpage::
+
+Shields
+^^^^^^^^^^^^
 
 .. rst:directive:: rtfd-shield
 
@@ -65,111 +66,20 @@ All shields have the following options:
 		.. versionadded:: 1.8.0
 
 
-	**Examples**
+	.. only:: html
 
-	.. rest-example::
+		**Examples**
 
-		.. rtfd-shield::
-			:project: sphinx-toolbox
+		.. rest-example::
 
-	.. rest-example::
+			.. rtfd-shield::
+				:project: sphinx-toolbox
 
-		.. rtfd-shield::
-			:project: attrs
-			:target: https://www.attrs.org/
+		.. rest-example::
 
-
-.. rst:directive:: actions-shield
-
-	Shield to show the *GitHub Actions* build status.
-
-	.. rst:directive:option:: username
-
-		The GitHub username. Defaults to :confval:`github_username`.
-
-	.. rst:directive:option:: repository
-
-		The GitHub repository. Defaults to :confval:`github_repository`.
-
-	.. rst:directive:option:: workflow
-
-		The workflow to show the status for.
-
-
-	**Example**
-
-	.. rest-example::
-
-		.. actions-shield::
-			:workflow: Windows Tests
-
-
-.. rst:directive:: requires-io-shield
-
-	Shield to show the *Requires.io* status.
-
-	.. rst:directive:option:: username
-
-		The GitHub username. Defaults to :confval:`github_username`.
-
-	.. rst:directive:option:: repository
-
-		The GitHub repository. Defaults to :confval:`github_repository`.
-
-	.. rst:directive:option:: branch
-
-		The branch to show the build status for. Default ``master``.
-
-
-	**Example**
-
-	.. rest-example::
-
-		.. requires-io-shield::
-
-
-.. rst:directive:: coveralls-shield
-
-	Shield to show the code coverage from `Coveralls.io <https://coveralls.io/>`_.
-
-	.. rst:directive:option:: username
-
-		The GitHub username. Defaults to :confval:`github_username`.
-
-	.. rst:directive:option:: repository
-
-		The GitHub repository. Defaults to :confval:`github_repository`.
-
-	.. rst:directive:option:: branch
-
-		The branch to show the build status for. Default ``master``.
-
-
-	**Example**
-
-	.. rest-example::
-
-		.. coveralls-shield::
-
-
-.. rst:directive:: codefactor-shield
-
-	Shield to show the code quality from `Codefactor <https://www.codefactor.io>`_.
-
-	.. rst:directive:option:: username
-
-		The GitHub username. Defaults to :confval:`github_username`.
-
-	.. rst:directive:option:: repository
-
-		The GitHub repository. Defaults to :confval:`github_repository`.
-
-
-	**Example**
-
-	.. rest-example::
-
-		.. codefactor-shield::
+			.. rtfd-shield::
+				:project: attrs
+				:target: https://www.attrs.org/
 
 
 .. rst:directive:: pypi-shield
@@ -206,19 +116,41 @@ All shields have the following options:
 
 		Show the downloads for the given period (day / week / month)
 
+		.. versionchanged:: 2.5.0  Shields created with this option now link to pypistats_.
 
-	**Examples**
+		.. _pypistats: https://pypistats.org
 
-	.. rest-example::
 
-		.. pypi-shield::
-			:version:
+	.. only:: html
 
-		\
+		**Examples**
 
-		.. pypi-shield::
-			:project: sphinx
-			:downloads: month
+		.. rest-example::
+
+			.. pypi-shield::
+				:version:
+
+			\
+
+			.. pypi-shield::
+				:project: sphinx
+				:downloads: month
+
+
+.. rst:directive:: maintained-shield
+
+	Shield to indicate whether the project is maintained.
+
+	Takes a single argument: the current year.
+
+
+	.. only:: html
+
+		**Example**
+
+		.. rest-example::
+
+			.. maintained-shield:: 2020
 
 
 .. rst:directive:: github-shield
@@ -267,31 +199,119 @@ All shields have the following options:
 		Show the license detected by GitHub.
 
 
-	**Examples**
+	.. only:: html
 
-	.. rest-example::
+		**Examples**
 
-		.. github-shield::
-			:last-commit:
+		.. rest-example::
 
-		\
+			.. github-shield::
+				:last-commit:
 
-		.. github-shield::
-			:commits-since: v0.1.0
+			\
+
+			.. github-shield::
+				:commits-since: v0.1.0
 
 
-.. rst:directive:: maintained-shield:
+.. rst:directive:: actions-shield
 
-	Shield to indicate whether the project is maintained.
+	Shield to show the *GitHub Actions* build status.
 
-	Takes a single argument: the current year.
+	.. rst:directive:option:: username
+
+		The GitHub username. Defaults to :confval:`github_username`.
+
+	.. rst:directive:option:: repository
+
+		The GitHub repository. Defaults to :confval:`github_repository`.
+
+	.. rst:directive:option:: workflow
+
+		The workflow to show the status for.
+
+	.. only:: html
+
+		**Example**
+
+		.. rest-example::
+
+			.. actions-shield::
+				:workflow: Windows Tests
 
 
-	**Example**
+.. rst:directive:: requires-io-shield
 
-	.. rest-example::
+	Shield to show the *Requires.io* status.
 
-		.. maintained-shield:: 2020
+	.. rst:directive:option:: username
+
+		The GitHub username. Defaults to :confval:`github_username`.
+
+	.. rst:directive:option:: repository
+
+		The GitHub repository. Defaults to :confval:`github_repository`.
+
+	.. rst:directive:option:: branch
+
+		The branch to show the build status for. Default ``master``.
+
+
+	.. only:: html
+
+		**Example**
+
+		.. rest-example::
+
+			.. requires-io-shield::
+
+
+.. rst:directive:: coveralls-shield
+
+	Shield to show the code coverage from `Coveralls.io <https://coveralls.io/>`_.
+
+	.. rst:directive:option:: username
+
+		The GitHub username. Defaults to :confval:`github_username`.
+
+	.. rst:directive:option:: repository
+
+		The GitHub repository. Defaults to :confval:`github_repository`.
+
+	.. rst:directive:option:: branch
+
+		The branch to show the build status for. Default ``master``.
+
+
+	.. only:: html
+
+		**Example**
+
+		.. rest-example::
+
+			.. coveralls-shield::
+
+
+.. rst:directive:: codefactor-shield
+
+	Shield to show the code quality score from `Codefactor <https://www.codefactor.io>`_.
+
+	.. rst:directive:option:: username
+
+		The GitHub username. Defaults to :confval:`github_username`.
+
+	.. rst:directive:option:: repository
+
+		The GitHub repository. Defaults to :confval:`github_repository`.
+
+
+	.. only:: html
+
+		**Example**
+
+		.. rest-example::
+
+			.. codefactor-shield::
 
 
 .. rst:directive:: pre-commit-shield
@@ -299,11 +319,13 @@ All shields have the following options:
 	Shield to indicate that the project uses `pre-commit <https://pre-commit.com/>`_.
 
 
-	**Example**
+	.. only:: html
 
-	.. rest-example::
+		**Example**
 
-		.. pre-commit-shield::
+		.. rest-example::
+
+			.. pre-commit-shield::
 
 
 .. rst:directive:: pre-commit-ci-shield
@@ -325,16 +347,19 @@ All shields have the following options:
 		The branch to show the status for. Default ``master``.
 
 
-	**Example**
+	.. only:: html
 
-	.. rest-example::
+		**Example**
 
-		.. pre-commit-ci-shield::
+		.. rest-example::
 
+			.. pre-commit-ci-shield::
 
-"""  # noqa RST299,RST305
+.. latex:vspace:: 5mm
+
+"""
 #
-#  Copyright © 2020 Dominic Davis-Foster <dominic@davis-foster.co.uk>
+#  Copyright © 2020-2021 Dominic Davis-Foster <dominic@davis-foster.co.uk>
 #
 #  Permission is hereby granted, free of charge, to any person obtaining a copy
 #  of this software and associated documentation files (the "Software"), to deal
@@ -358,37 +383,43 @@ All shields have the following options:
 #
 
 # stdlib
-from typing import List
+from typing import List, Optional, Tuple
 from urllib.parse import quote
 
 # 3rd party
+import dict2css
+import docutils
 from apeye.url import URL
 from docutils import nodes
 from docutils.nodes import fully_normalize_name, whitespace_normalize_name
-from docutils.parsers.rst import directives, states
+from docutils.parsers.rst import directives
 from docutils.parsers.rst.roles import set_classes
+from domdf_python_tools.paths import PathPlus
 from sphinx.application import Sphinx
 from sphinx.util.docutils import SphinxDirective
 
 # this package
+from sphinx_toolbox import _css
 from sphinx_toolbox.utils import OptionSpec, SphinxExtMetadata, flag, make_github_url, metadata_add_version
 
-__all__ = [
+__all__ = (
 		"SHIELDS_IO",
 		"shield_default_option_spec",
 		"Shield",
-		"GitHubBackedShield",
 		"RTFDShield",
+		"PyPIShield",
+		"MaintainedShield",
+		"GitHubBackedShield",
+		"GitHubShield",
 		"GitHubActionsShield",
 		"RequiresIOShield",
 		"CoverallsShield",
 		"CodefactorShield",
-		"PyPIShield",
-		"GitHubShield",
-		"MaintainedShield",
 		"PreCommitShield",
 		"PreCommitCIShield",
-		]
+		"copy_asset_files",
+		"setup",
+		)
 
 #: Base URL for shields.io
 SHIELDS_IO = URL("https://img.shields.io")
@@ -412,7 +443,7 @@ class Shield(SphinxDirective):
 	required_arguments = 1
 	optional_arguments = 0
 	final_argument_whitespace = True
-	option_spec: OptionSpec = {  # type: ignore
+	option_spec: OptionSpec = {  # type: ignore[assignment]
 		"target": directives.unchanged_required,
 		**shield_default_option_spec,
 		}
@@ -435,10 +466,10 @@ class Shield(SphinxDirective):
 		reference_node = None
 
 		if "target" in self.options:
-			block = states.escape2null(self.options["target"]).splitlines()  # type: ignore
+			block = docutils.utils.escape2null(self.options["target"]).splitlines()
 			block = [line for line in block]
 
-			target_type, data = self.state.parse_target(block, self.block_text, self.lineno)  # type: ignore
+			target_type, data = self.state.parse_target(block, self.block_text, self.lineno)  # type: ignore[attr-defined]
 
 			if target_type == "refuri":
 				reference_node = nodes.reference(refuri=data)
@@ -447,7 +478,7 @@ class Shield(SphinxDirective):
 						refname=fully_normalize_name(data),
 						name=whitespace_normalize_name(data),
 						)
-				reference_node.indirect_reference_name = data  # type: ignore
+				reference_node.indirect_reference_name = data  # type: ignore[attr-defined]
 				self.state.document.note_refname(reference_node)
 			else:  # pragma: no cover
 				# malformed target
@@ -479,7 +510,7 @@ class GitHubBackedShield(Shield):
 			**shield_default_option_spec,
 			}
 
-	def get_repo_details(self):
+	def get_repo_details(self) -> Tuple[str, str]:
 		"""
 		Returns the username and repository name, either parsed from the directive's options or from ``conf.py``.
 		"""
@@ -579,7 +610,7 @@ class RequiresIOShield(GitHubBackedShield):
 		branch = self.options.pop("branch", "master")
 		base_url = URL("https://requires.io/github/") / username / repository
 
-		self.arguments = [base_url / f"requirements.svg?branch={branch}"]
+		self.arguments = [str(base_url / f"requirements.svg?branch={branch}")]
 		self.options["target"] = str(base_url / f"requirements/?branch={branch}")
 
 		return super().run()
@@ -605,7 +636,8 @@ class CoverallsShield(GitHubBackedShield):
 		username, repository = self.get_repo_details()
 		branch = self.options.pop("branch", "master")
 
-		self.arguments = [SHIELDS_IO / "coveralls" / "github" / username / repository / f"{branch}?logo=coveralls"]
+		url = SHIELDS_IO / "coveralls" / "github" / username / repository / f"{branch}?logo=coveralls"
+		self.arguments = [str(url)]
 		self.options["target"] = f"https://coveralls.io/github/{username}/{repository}?branch={branch}"
 
 		return super().run()
@@ -613,7 +645,7 @@ class CoverallsShield(GitHubBackedShield):
 
 class CodefactorShield(GitHubBackedShield):
 	"""
-	Shield to show the code quality from `Codefactor <https://www.codefactor.io>`_.
+	Shield to show the code quality score from `Codefactor <https://www.codefactor.io>`_.
 	"""
 
 	def run(self) -> List[nodes.Node]:
@@ -624,7 +656,7 @@ class CodefactorShield(GitHubBackedShield):
 		username, repository = self.get_repo_details()
 
 		url = SHIELDS_IO / "codefactor" / "grade" / "github" / username / f"{repository}?logo=codefactor"
-		self.arguments = [url]
+		self.arguments = [str(url)]
 		self.options["target"] = f"https://codefactor.io/repository/github/{username}/{repository}"
 
 		return super().run()
@@ -692,6 +724,8 @@ class PyPIShield(Shield):
 			else:
 				raise ValueError("Unknown time period for the PyPI download statistics.")
 
+			self.options["target"] = f"https://pypistats.org/packages/{project.lower()}"
+
 		return super().run()
 
 
@@ -820,21 +854,44 @@ class PreCommitCIShield(GitHubBackedShield):
 		username, repository = self.get_repo_details()
 		branch = self.options.pop("branch", "master")
 
-		self.arguments = [RESULTS_PRE_COMMIT_CI / "badge" / "github" / username / repository / f"{branch}.svg"]
+		url = RESULTS_PRE_COMMIT_CI / "badge" / "github" / username / repository / f"{branch}.svg"
+		self.arguments = [str(url)]
 		self.options["target"] = str(RESULTS_PRE_COMMIT_CI / "latest" / "github" / username / repository / branch)
 
 		return super().run()
 
 
+def copy_asset_files(app: Sphinx, exception: Optional[Exception] = None) -> None:
+	"""
+	Copy additional stylesheets into the HTML build directory.
+
+	.. versionadded:: 2.3.1
+
+	:param app: The Sphinx application.
+	:param exception: Any exception which occurred and caused Sphinx to abort.
+	"""
+
+	if exception:  # pragma: no cover
+		return
+
+	if app.builder is None or app.builder.format.lower() != "html":  # pragma: no cover
+		return
+
+	static_dir = PathPlus(app.outdir) / "_static"
+	static_dir.maybe_make(parents=True)
+	dict2css.dump(_css.shields_styles, static_dir / "toolbox-shields.css", minify=True)
+
+
 @metadata_add_version
 def setup(app: Sphinx) -> SphinxExtMetadata:
 	"""
 	Setup :mod:`sphinx_toolbox.shields`.
 
-	:param app: The Sphinx app.
+	:param app: The Sphinx application.
 	"""
 
 	app.setup_extension("sphinx_toolbox.github")
+	app.setup_extension("sphinx_toolbox._css")
 
 	# Shields/badges
 	app.add_directive("rtfd-shield", RTFDShield)
