@@ -1,5 +1,6 @@
 # stdlib
 from http import HTTPStatus
+from types import SimpleNamespace
 from typing import Any, Dict, NamedTuple, Sequence, Tuple
 
 # 3rd party
@@ -30,10 +31,18 @@ class AppParams(NamedTuple):
 
 def get_app_config_values(config: Any) -> Tuple[str, str, Any]:
 	if sphinx.version_info >= (7, 3):
-		# valid_types =
 		valid_types = config.valid_types
-		if isinstance(valid_types, (set, frozenset)):
-			valid_types = list(valid_types)
-		return (config.default, config.rebuild, valid_types)
+		default = config.default
+		rebuild = config.rebuild
 	else:
-		return config
+		default, rebuild, valid_types = config
+
+	if isinstance(valid_types, (set, frozenset, tuple, list)):
+		valid_types = sorted(valid_types)
+
+	if hasattr(valid_types, "_candidates"):
+		new_valid_types = SimpleNamespace()
+		new_valid_types.candidates = sorted(valid_types._candidates)
+		valid_types = new_valid_types
+
+	return (default, rebuild, valid_types)
