@@ -11,7 +11,7 @@ extensions = [
 		"sphinx_toolbox.more_autodoc.autoprotocol",
 		]
 
-github_username = "domdfcoding"
+github_username = "sphinx-toolbox"
 github_repository = "sphinx-toolbox"
 source_link_target = "GitHub"
 generic_bases_fully_qualified = True
