@@ -3,7 +3,7 @@ extensions = [
 		"sphinx_toolbox",
 		]
 
-github_username = "domdfcoding"
+github_username = "sphinx-toolbox"
 github_repository = "sphinx-toolbox"
 source_link_target = "GitHub"
 project = "Python"
